@@ -57,8 +57,8 @@ static gboolean m_bUsChangingName;
 static GokFilledCombo* m_pGokFilledComboFirst;
 
 /**
-* gok-settings-page-accessmethod-initialize
-* @pWindowSettings: Pointer to the settings dialog window.
+* gok_page_accessmethod_initialize
+* @xml: Pointer to the Glade UI description of the settings dialog.
 *
 * Initializes this page of the gok settings dialog. This must be called
 * prior to any calls on this page.
@@ -549,19 +549,20 @@ void gok_page_accessmethod_update_controls (gchar* NameAccessMethod, GokControl*
 * gok_page_accessmethod_draw_controls
 * @NameAccessMethod: Name of the access methods that needs the controls.
 * @pControlParent: Pointer to the GOK control that will contain the new controls.
-* @pContainter: Pointer to the container widget for the controls.
 * @pControl: Pointer to the GokControl that you want drawn.
+* @pSizeGroup: Pointer to the GtkSizeGroup the control belongs to.
 * @bShow: If TRUE then the controls will be show, if FALSE they will be hidden.
 * 
 * Draws the controls for the GokControl.
 **/
-void gok_page_accessmethod_draw_controls (gchar* NameAccessMethod, GokControl* pControlParent, GokControl* pControl, gboolean bShow)
+void gok_page_accessmethod_draw_controls (gchar* NameAccessMethod, GokControl* pControlParent, GokControl* pControl, GtkSizeGroup* pSizeGroup, gboolean bShow)
 {
 	GtkWidget* pWidget;
 	GtkWidget* pEntry;
 	static GSList* ListRadioButtons;
 	GtkObject* spinRateAdjustment;
 	gchar* pControlName;
+	gchar* pFrameHeader;
 	int settingInt;
 	gchar* settingString;
 	GokFilledCombo* pFilledComboNew;
@@ -579,15 +580,21 @@ void gok_page_accessmethod_draw_controls (gchar* NameAccessMethod, GokControl* p
 			}
 			else /* create the control */
 			{
+				/* create a new size group */
+				if (pSizeGroup == NULL)
+					pSizeGroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+
 				switch (pControl->Type)
 				{
 					case CONTROL_TYPE_LABEL:
-						pWidget = gtk_label_new (_(pControl->String));
+						pWidget = gtk_label_new (pControl->String);
+						g_object_set (pWidget, "xalign", 0., NULL);
 						gtk_widget_ref (pWidget);
 						gtk_object_set_data_full (GTK_OBJECT (gok_settingsdialog_get_window()), "GOKlabel", pWidget,
 						                            (GtkDestroyNotify) gtk_widget_unref);
 						gtk_widget_show (pWidget);
 						gtk_box_pack_start (GTK_BOX (pControlParent->pWidget), pWidget, FALSE, FALSE, 0);
+						gtk_size_group_add_widget (pSizeGroup, pWidget);
 						break;
 						
 					case CONTROL_TYPE_HBOX:
@@ -595,6 +602,7 @@ void gok_page_accessmethod_draw_controls (gchar* NameAccessMethod, GokControl* p
 						gtk_widget_ref (pWidget);
 						gtk_object_set_data_full (GTK_OBJECT (gok_settingsdialog_get_window()), "GOKhbox", pWidget,
 						                            (GtkDestroyNotify) gtk_widget_unref);
+						gtk_container_set_border_width (GTK_CONTAINER (pWidget), pControl->Border);
 						gtk_widget_show (pWidget);
 						
 						if (pControlParent->Type == CONTROL_TYPE_FRAME)
@@ -604,7 +612,6 @@ void gok_page_accessmethod_draw_controls (gchar* NameAccessMethod, GokControl* p
 						else
 						{
 							gtk_box_pack_start (GTK_BOX (pControlParent->pWidget), pWidget, TRUE, TRUE, 0);
-							gtk_container_set_border_width (GTK_CONTAINER (pControlParent->pWidget), pControl->Border);
 						}
 						break;
 						
@@ -613,6 +620,7 @@ void gok_page_accessmethod_draw_controls (gchar* NameAccessMethod, GokControl* p
 						gtk_widget_ref (pWidget);
 						gtk_object_set_data_full (GTK_OBJECT (gok_settingsdialog_get_window()), "GOKvbox", pWidget,
 						                            (GtkDestroyNotify) gtk_widget_unref);
+						gtk_container_set_border_width (GTK_CONTAINER (pWidget), pControl->Border);
 						gtk_widget_show (pWidget);
 						
 						if (pControlParent->Type == CONTROL_TYPE_FRAME)
@@ -622,7 +630,6 @@ void gok_page_accessmethod_draw_controls (gchar* NameAccessMethod, GokControl* p
 						else
 						{
 							gtk_box_pack_start (GTK_BOX (pControlParent->pWidget), pWidget, TRUE, TRUE, 0);
-							gtk_container_set_border_width (GTK_CONTAINER (pControlParent->pWidget), pControl->Border);
 						}
 						break;
 						
@@ -678,17 +685,21 @@ void gok_page_accessmethod_draw_controls (gchar* NameAccessMethod, GokControl* p
 						break;
 						
 					case CONTROL_TYPE_FRAME:
-						pWidget = gtk_frame_new (_(pControl->String));
+						pFrameHeader = g_markup_printf_escaped ("<b>%s</b>", pControl->String);
+						pWidget = gtk_frame_new (pFrameHeader);
+						g_free (pFrameHeader);
 						gtk_widget_ref (pWidget);
 						gtk_object_set_data_full (GTK_OBJECT (gok_settingsdialog_get_window()), "GOKframe", pWidget,
 						                            (GtkDestroyNotify) gtk_widget_unref);
+						gtk_label_set_use_markup (GTK_LABEL (gtk_frame_get_label_widget (GTK_FRAME (pWidget))), TRUE);
+						gtk_frame_set_shadow_type (GTK_FRAME (pWidget), GTK_SHADOW_NONE);
 						gtk_widget_show (pWidget);
 						gtk_box_pack_start (GTK_BOX (pControlParent->pWidget), pWidget, FALSE, FALSE, 0);
 						break;
 						
 					case CONTROL_TYPE_BUTTON:
 						pControlName = (pControl->Name != NULL) ? pControl->Name : "button";
-						pWidget = gtk_button_new_with_label (_(pControl->String));
+						pWidget = gtk_button_new_with_label (pControl->String);
 						gtk_widget_ref (pWidget);
 						gtk_object_set_data_full (GTK_OBJECT (gok_settingsdialog_get_window()), pControlName, pWidget,
 						                            (GtkDestroyNotify) gtk_widget_unref);
@@ -699,7 +710,7 @@ void gok_page_accessmethod_draw_controls (gchar* NameAccessMethod, GokControl* p
 						break;
 						
 					case CONTROL_TYPE_CHECKBUTTON:
-						pWidget = gtk_check_button_new_with_label (_(pControl->String));
+						pWidget = gtk_check_button_new_with_label (pControl->String);
 						gtk_widget_ref (pWidget);
 						gtk_object_set_data_full (GTK_OBJECT (gok_settingsdialog_get_window()), "GOKcheckbutton", pWidget,
 						                            (GtkDestroyNotify) gtk_widget_unref);
@@ -728,7 +739,7 @@ void gok_page_accessmethod_draw_controls (gchar* NameAccessMethod, GokControl* p
 							ListRadioButtons = NULL;
 						}
 
-						pWidget = gtk_radio_button_new_with_label (ListRadioButtons, _(pControl->String));
+						pWidget = gtk_radio_button_new_with_label (ListRadioButtons, pControl->String);
 						ListRadioButtons = gtk_radio_button_group (GTK_RADIO_BUTTON (pWidget));
 						gtk_widget_ref (pWidget);
 						gtk_object_set_data_full (GTK_OBJECT (gok_settingsdialog_get_window()), "GOKradiobutton", pWidget,
@@ -788,7 +799,7 @@ void gok_page_accessmethod_draw_controls (gchar* NameAccessMethod, GokControl* p
 		/* create any child controls */
 		if (pControl->pControlChild != NULL)
 		{
-			gok_page_accessmethod_draw_controls (NameAccessMethod, pControl, pControl->pControlChild, bShow);
+			gok_page_accessmethod_draw_controls (NameAccessMethod, pControl, pControl->pControlChild, pSizeGroup, bShow);
 		}
 
 		pControl = pControl->pControlNext;
@@ -907,9 +918,9 @@ void gok_page_accessmethod_change_controls (gchar* pNameAccessMethod)
 			/* hide the controls from the previous access method */
 			if (m_pAccessMethod != NULL)
 			{
-				gok_page_accessmethod_draw_controls (pNameAccessMethod, &ControlParent, m_pAccessMethod->pControlOperation, FALSE);
-				gok_page_accessmethod_draw_controls (pNameAccessMethod, &ControlParent, m_pAccessMethod->pControlFeedback, FALSE);
-				gok_page_accessmethod_draw_controls (pNameAccessMethod, &ControlParent, m_pAccessMethod->pControlOptions, FALSE);
+				gok_page_accessmethod_draw_controls (pNameAccessMethod, &ControlParent, m_pAccessMethod->pControlOperation, NULL, FALSE);
+				gok_page_accessmethod_draw_controls (pNameAccessMethod, &ControlParent, m_pAccessMethod->pControlFeedback, NULL, FALSE);
+				gok_page_accessmethod_draw_controls (pNameAccessMethod, &ControlParent, m_pAccessMethod->pControlOptions, NULL, FALSE);
 			}
 
 			/* store the new access method */
@@ -930,9 +941,9 @@ void gok_page_accessmethod_change_controls (gchar* pNameAccessMethod)
 			gtk_label_set_text (GTK_LABEL (pLabelDescription), pAccessMethod->Description);
 				
 			/* display the controls for the selected access method */
-			gok_page_accessmethod_draw_controls (pNameAccessMethod, &ControlParent, pAccessMethod->pControlOperation, TRUE);
-			gok_page_accessmethod_draw_controls (pNameAccessMethod, &ControlParent, pAccessMethod->pControlFeedback, TRUE);
-			gok_page_accessmethod_draw_controls (pNameAccessMethod, &ControlParent, pAccessMethod->pControlOptions, TRUE);
+			gok_page_accessmethod_draw_controls (pNameAccessMethod, &ControlParent, pAccessMethod->pControlOperation, NULL, TRUE);
+			gok_page_accessmethod_draw_controls (pNameAccessMethod, &ControlParent, pAccessMethod->pControlFeedback, NULL, TRUE);
+			gok_page_accessmethod_draw_controls (pNameAccessMethod, &ControlParent, pAccessMethod->pControlOptions, NULL, TRUE);
 
 			gok_page_accessmethod_update_associated (pAccessMethod);
 			return;
